import { InvalidValueError } from '@crosslab/service-common';
import { logger } from '@crosslab/service-common';
import { config } from '../../config.js';
import { callbackHandler } from './callbackHandler.js';
export const callbackUrl = config.BASE_URL + (config.BASE_URL.endsWith('/') ? '' : '/') + `callbacks/experiment`;
export const peerconnectionClosedCallbacks = [];
export const peerconnectionStatusChangedCallbacks = [];
export const deviceChangedCallbacks = new Map();
/**
 * This function adds the endpoint for incoming callbacks registered by the experiment service.
 * @param app The express application the callback endpoint should be added to.
 */
export function callbackHandling(app) {
    app.post('/callbacks/experiment', async (req, res, next) => {
        try {
            const callback = req.body;
            logger.log('info', 'received a callback', { data: { callback } });
            if (!('callbackType' in callback)) {
                callback.callbackType = 'event';
                callback.eventType = 'booking-changed';
            }
            switch (callback.callbackType) {
                case 'event':
                    return res.status(await callbackHandler.handleEventCallback(callback)).send();
                default:
                    throw new InvalidValueError(`Callbacks of type "${callback.callbackType}" are not supported`, 400);
            }
        }
        catch (error) {
            return next(error);
        }
    });
}
//# sourceMappingURL=index.js.map